@@ -16,7 +16,7 @@ if detector.chip.BCM2XXX:
 elif detector.chip.AM33XX:
     from adafruit_blinka.microcontroller.am335x.pin import Pin
 elif detector.chip.SUN8I:
-    from adafruit_blinka.microcontroller.allwinner_h3.pin import Pin
+    from adafruit_blinka.microcontroller.allwinner.h3.pin import Pin
 elif detector.chip.SAMA5:
     from adafruit_blinka.microcontroller.sama5.pin import Pin
 elif detector.chip.T210:
@@ -27,12 +27,24 @@ elif detector.chip.T194:
     from adafruit_blinka.microcontroller.tegra.t194.pin import Pin
 elif detector.chip.S905:
     from adafruit_blinka.microcontroller.amlogic.s905.pin import Pin
+elif detector.chip.S905X3:
+    from adafruit_blinka.microcontroller.amlogic.s905x3.pin import Pin
 elif detector.chip.S922X:
     from adafruit_blinka.microcontroller.amlogic.s922x.pin import Pin
 elif detector.chip.APQ8016:
     from adafruit_blinka.microcontroller.snapdragon.apq8016.pin import Pin
 elif detector.chip.IMX8MX:
     from adafruit_blinka.microcontroller.nxp_imx8m.pin import Pin
+elif detector.chip.HFU540:
+    from adafruit_blinka.microcontroller.hfu540.pin import Pin
+elif detector.chip.A64:
+    from adafruit_blinka.microcontroller.allwinner.a64.pin import Pin
+elif detector.chip.A33:
+    from adafruit_blinka.microcontroller.allwinner.a33.pin import Pin
+elif detector.chip.MIPS24KEC:
+    from adafruit_blinka.microcontroller.mips24kec.pin import Pin
+elif detector.chip.RK3308:
+    from adafruit_blinka.microcontroller.rockchip.rk3308.pin import Pin
 elif detector.board.ftdi_ft232h:
     from adafruit_blinka.microcontroller.ft232h.pin import Pin
 elif detector.board.binho_nova:
@@ -43,6 +55,7 @@ elif detector.board.microchip_mcp2221:
     from adafruit_blinka.microcontroller.mcp2221.pin import Pin
 from adafruit_blinka import Enum, ContextManaged
 
+
 class DriveMode(Enum):
     PUSH_PULL = None
     OPEN_DRAIN = None
@@ -64,13 +77,13 @@ Direction.OUTPUT = Direction()
 class Pull(Enum):
     UP = None
     DOWN = None
-    #NONE=None
+    # NONE=None
 
 
 Pull.UP = Pull()
 Pull.DOWN = Pull()
 
-#Pull.NONE = Pull()
+# Pull.NONE = Pull()
 
 
 class DigitalInOut(ContextManaged):
@@ -111,7 +124,7 @@ class DigitalInOut(ContextManaged):
 
     @property
     def value(self):
-        return self._pin.value() is 1
+        return self._pin.value() == 1
 
     @value.setter
     def value(self, val):
@@ -137,8 +150,9 @@ class DigitalInOut(ContextManaged):
                 if hasattr(Pin, "PULL_DOWN"):
                     self._pin.init(mode=Pin.IN, pull=Pin.PULL_DOWN)
                 else:
-                    raise NotImplementedError("{} unsupported on {}".format(
-                        Pull.DOWN, board_id))
+                    raise NotImplementedError(
+                        "{} unsupported on {}".format(Pull.DOWN, board_id)
+                    )
             elif pul is None:
                 self._pin.init(mode=Pin.IN, pull=None)
             else:
